@@ -7,14 +7,12 @@
 
   S=Stot[index, index]
 
-
-
   if (length(index)>1)
   {
-    ressvd=.firstEig(S)
-    u=ressvd$u
+    ressvd=svd(S)
+    u=ressvd$u[,1]
     u=u*sign(u[1])
-    lambda=ressvd$lambda
+    lambda=ressvd$d[1]
   }else{
     u=1
     lambda=1
@@ -25,15 +23,7 @@
   for (j in 1:nblo) { C=C+(u[j]*Xj[[j]]) }
 
 
-  # the sum of distances between the weighted scalar product matrices
-  # and the consensus
-  dw=rep(0,nblo)
-  normW=sum(diag(C%*%t(C)))
-  for (j in 1:nblo) {
-    a=Xj[[j]]-(u[j]*C)
-    dw[j]=sum(diag(a%*%t(a)))
-  }
-  Q=sum(dw)
+  Q=nblo-lambda
 
   return(list(S=S,C=C,alpha=u,lambda=lambda,Q=Q))
 
